# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['optfunc2']

package_data = \
{'': ['*']}

install_requires = \
['docstring_parser>=0.16,<0.17', 'prettytable>=3.14.0,<4.0.0']

setup_kwargs = {
    'name': 'optfunc2',
    'version': '0.2.1',
    'description': 'Generate options from function.',
    'long_description': '# Call function directly in cmd line\n\n### Features\n1. Allow user call functions directly in command line.\n2. Generate help tips automatically.\n3. Add default called functions if not function was specific.\n\n### Notice\n1. It\'s better to add argument type for each autocall functions.\n2. Function with @optfunc_default has @optfunc implicitly.\n3. Arguments of function with @optfunc_default should be optional or no argument.\n4. Not support two type of variadic arguments.\n\n### ChangeLog\n#### 0.2.1 (2025-2-14)\n1. Fix installing dependencies automatically.\n2. Add function \'called_directly\' used to check if the function is called as entry point.\n   This function can be used in function development.\n   \n#### 0.1.2 (2023-05-06)\n1. Add support for default called functions.\n2. Fix README.md.\n3. Add ChangeLog in README.md.\n\n### Code example\n``` python\nfrom optfunc2 import *\n\n@optfunc\ndef arg_test_positional_only(pos_only0, pos_only1: int, pos_only2 = 5, pos_only3: int = 6):\n    """summary for the function\n\n    Args:\n        pos_only0 (_type_): This is the first positional-only argument.\n        pos_only1 (int): This is the second positional-only argument.\n        pos_only2 (int, optional): This is the third positional-only argument. Defaults to 5.\n        pos_only3 (int, optional): This is the fourth positional-only argument. Defaults to 6.\n    """\n    " Argument test for positional-only arguments. "\n    print(f\'pos_only0: {pos_only0}, pos_only1: {pos_only1}, pos_only2: {pos_only2}, pos_only3: {pos_only3}\')\n    pass\n\n@optfunc\ndef arg_test_positional_or_keyword(pos_or_kw, pos_or_kw1: int, pos_or_kw2 = 3, pos_or_kw3: int = 4):\n    " Argument test for positional-or-keyword arguments. "\n    print(f\'pos_or_kw: {pos_or_kw}, pos_or_kw1: {pos_or_kw1}, pos_or_kw2: {pos_or_kw2}, pos_or_kw3: {pos_or_kw3}\')\n    pass\n\n@optfunc\ndef arg_test_kw_only(*, kw_only0, kw_only1: int, kw_only2 = 9, kw_only3: int = 10):\n    " Argument test for keyword-only arguments. "\n    print(f\'kw_only0: {kw_only0}, kw_only1: {kw_only1}, kw_only2: {kw_only2}, kw_only3: {kw_only3}\')\n    pass\n\nif __name__ == \'__main__\':\n    optfunc_start(globals=globals(), has_abbrev=False, header_doc=\'This is a test file for the module "autocall".\')\n```\n### Run the code\n``` bash\n~/:$ python3 test.py -h\nUsage: test.py [command] [<args>|--help]\n\nThis is a test file for the module "autocall".\n\ncommands:\n    arg_test_positional_only           summary for the function\n    arg_test_positional_or_keyword     Argument test for positional-or-keyword arguments.\n    arg_test_kw_only                   Argument test for keyword-only arguments.\n\n~/:$ python3 test.py arg_test_positional_only -h\nUsage: test.py arg_test_positional_only [OPTIONS]\n\nsummary for the function\n\n\nArguments:\n+-------------+------+---------+-------------------------------------------------------------+\n|     Opt     | Type | Default |                             Desc                            |\n+-------------+------+---------+-------------------------------------------------------------+\n| --pos_only0 | any  |         |         This is the first positional-only argument.         |\n| --pos_only1 | int  |         |         This is the second positional-only argument.        |\n| --pos_only2 | any  |    5    |  This is the third positional-only argument. Defaults to 5. |\n| --pos_only3 | int  |    6    | This is the fourth positional-only argument. Defaults to 6. |\n+-------------+------+---------+-------------------------------------------------------------+\n~/:$ python3 test.py arg_test_positional_only --pos_only0 "good day" --pos_only1 2\npos_only0: good day, pos_only1: 2, pos_only2: 5, pos_only3: 6\n```\n',
    'author': 'bajeer',
    'author_email': 'z_bajer@yeah.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
